$OpenBSD: patch-plugins_video_common_ffmpeg_libavcodec_avcodec_h,v 1.1 2013/11/02 15:55:53 ajacoutot Exp $

Fix compilation/runtime with ffmpeg 0.11 (Arch Linux):
https://projects.archlinux.org/svntogit/packages.git/tree/trunk/opal-ffmpeg.patch?h=packages/opal

--- plugins/video/common/ffmpeg/libavcodec/avcodec.h.orig	Thu Aug 15 01:22:47 2013
+++ plugins/video/common/ffmpeg/libavcodec/avcodec.h	Sat Nov  2 16:28:49 2013
@@ -101,7 +101,7 @@
  * 1. no value of a existing codec ID changes (that would break ABI),
  * 2. it is as close as possible to similar codecs.
  */
-enum CodecID {
+enum AVCodecID {
     CODEC_ID_NONE,
 
     /* video codecs */
@@ -1390,7 +1390,7 @@ typedef struct AVCodecContext {
 
     char codec_name[32];
     enum AVMediaType codec_type; /* see AVMEDIA_TYPE_xxx */
-    enum CodecID codec_id; /* see CODEC_ID_xxx */
+    enum AVCodecID codec_id; /* see CODEC_ID_xxx */
 
     /**
      * fourcc (LSB first, so "ABCD" -> ('D'<<24) + ('C'<<16) + ('B'<<8) + 'A').
@@ -2843,7 +2843,7 @@ typedef struct AVCodec {
      */
     const char *name;
     enum AVMediaType type;
-    enum CodecID id;
+    enum AVCodecID id;
     int priv_data_size;
     int (*init)(AVCodecContext *);
     int (*encode)(AVCodecContext *, uint8_t *buf, int buf_size, void *data);
@@ -2898,7 +2898,7 @@ typedef struct AVHWAccel {
      *
      * See CODEC_ID_xxx
      */
-    enum CodecID id;
+    enum AVCodecID id;
 
     /**
      * Supported pixel format.
@@ -3402,10 +3402,10 @@ void avcodec_register(AVCodec *codec);
 /**
  * Find a registered encoder with a matching codec ID.
  *
  * @param id CodecID of the requested encoder
  * @return An encoder if one was found, NULL otherwise.
  */
-AVCodec *avcodec_find_encoder(enum CodecID id);
+AVCodec *avcodec_find_encoder(enum AVCodecID id);
 
 /**
  * Find a registered encoder with the specified name.
@@ -3418,10 +3418,10 @@ AVCodec *avcodec_find_encoder_by_name(const char *name
 /**
  * Find a registered decoder with a matching codec ID.
  *
  * @param id CodecID of the requested decoder
  * @return A decoder if one was found, NULL otherwise.
  */
-AVCodec *avcodec_find_decoder(enum CodecID id);
+AVCodec *avcodec_find_decoder(enum AVCodecID id);
 
 /**
  * Find a registered decoder with the specified name.
@@ -3822,7 +3822,7 @@ char av_get_pict_type_char(int pict_type);
  * @param[in] codec_id the codec
  * @return Number of bits per sample or zero if unknown for the given codec.
  */
-int av_get_bits_per_sample(enum CodecID codec_id);
+int av_get_bits_per_sample(enum AVCodecID codec_id);
 
 #if FF_API_OLD_SAMPLE_FMT
 /**
@@ -3402,10 +3402,10 @@ void avcodec_register(AVCodec *codec);
  * Find a registered encoder with a matching codec ID.
  *
- * @param id CodecID of the requested encoder
+ * @param id AVCodecID of the requested encoder
  * @return An encoder if one was found, NULL otherwise.
  */
@@ -3418,10 +3418,10 @@ AVCodec *avcodec_find_encoder_by_name(const char *name
  * Find a registered decoder with a matching codec ID.
  *
- * @param id CodecID of the requested decoder
+ * @param id AVCodecID of the requested decoder
  * @return A decoder if one was found, NULL otherwise.
  */
